@@ -1,6 +1,5 @@
-context("test-ssm_visualization.R")
-
 test_that("Single-group mean-based SSM plot is correct", {
+  skip_if(getRversion() > 4.0)
   data("aw2009")
   res <- ssm_analyze(aw2009, PA:NO, octants())
   p <- ssm_plot(res)
@@ -8,21 +7,25 @@ test_that("Single-group mean-based SSM plot is correct", {
   # Test the output object
   expect_type(p, "list")
   expect_s3_class(p, "ggplot")
+  vdiffr::expect_doppelganger("single group mean ssm", p, path = "ssm-visualization")
 
   # TODO: Add tests of transformed data and legend
 })
 
 test_that("Single-group correlation-based SSM plot is correct", {
+  skip_if(getRversion() > 4.0)
   data("jz2017")
   res <- ssm_analyze(jz2017, PA:NO, octants(), measures = PARPD)
   p <- ssm_plot(res)
-
+  
   # Test the output object
   expect_type(p, "list")
   expect_s3_class(p, "ggplot")
+  vdiffr::expect_doppelganger("single group correlation ssm", p, path = "ssm-visualization")
 })
 
 test_that("Measure-contrast SSM plot is correct", {
+  skip_if(getRversion() > 4.0)
   data("jz2017")
   res <- ssm_analyze(jz2017, PA:NO, octants(),
     measures = c(ASPD, NARPD),
@@ -33,9 +36,11 @@ test_that("Measure-contrast SSM plot is correct", {
   # Test the output object
   expect_type(p, "list")
   expect_s3_class(p, "ggplot")
+  vdiffr::expect_doppelganger("measure-contrast ssm", p, path = "ssm-visualization")
 })
 
 test_that("Group-contrast correlation-based SSM plot is correct", {
+  skip_if(getRversion() > 4.0)
   data("jz2017")
   res <- ssm_analyze(jz2017, PA:NO, octants(),
     measures = NARPD,
@@ -46,6 +51,7 @@ test_that("Group-contrast correlation-based SSM plot is correct", {
   # Test the output object
   expect_type(p, "list")
   expect_s3_class(p, "ggplot")
+  vdiffr::expect_doppelganger("group-constrast correlation ssm", p, path = "ssm-visualization")
 })
 
 test_that("Removing plots with low fit works as expected", {
